==> xwidgetsbase-5.0.2.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItem.dart <==
part of xwidgetbase;

class XItem extends StatelessWidget {
  final bool labelOnTop;
  final String? label;
  final Color? colorCard;
  final Color? colorLabel;
  final TextStyle? labelStyle;
  final TextAlign labelTextAlign;
  final AlignmentGeometry? labelAlignOnTop;
  AlignmentGeometry? labelAlignOnLeft;
  final CrossAxisAlignment? crossAxisAlignmentLabelOnTop;
  final Widget? labelWidget;
  final List<Widget>? children;
  double labelWidth;
  double? labelHeight;
  final bool visibleBottomBorderOfCard;
  final CrossAxisAlignment? childrensCrossAxisAlignment;
  final BoxConstraints? constraints;
  final Color? colorBackGroungTitleContainer;
  final double? widthBorderTitleContainer;
  final Function()? onTap;
  final MainAxisAlignment? mainAxisAlignmentLabelOnTop;
  XItem({
    Key? key,
    this.onTap,
    this.labelAlignOnTop,
    this.mainAxisAlignmentLabelOnTop,
    this.labelWidget,
    this.crossAxisAlignmentLabelOnTop,
    this.colorCard,
    this.labelStyle,
    this.labelAlignOnLeft,
    this.visibleBottomBorderOfCard = false,
    this.colorLabel,
    this.label = "",
    this.labelWidth = 150,
    this.labelHeight,
    this.children,
    this.childrensCrossAxisAlignment,
    this.labelOnTop = false,
    this.labelTextAlign = TextAlign.center,
    this.colorBackGroungTitleContainer,
    this.widthBorderTitleContainer,
    double? width,
    double? height,
    BoxConstraints? constraints,
  })  : constraints = (width != null || height != null) ? constraints?.tighten(width: width, height: height) ?? BoxConstraints.tightFor(width: width, height: height) : constraints,
        super(key: key);
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
        onTap: onTap,
        child: ConstrainedBox(
          constraints: constraints ?? BoxConstraints(),
          child: Container(
            child: Card(
              color: colorCard ?? Colors.transparent,
              child: Container(
                  decoration: visibleBottomBorderOfCard == true ? BoxDecoration(border: Border(bottom: BorderSide(width: 6, color: Colors.blue.withOpacity(0.5)))) : null,
                  child: Column(
                    mainAxisAlignment: mainAxisAlignmentLabelOnTop ?? MainAxisAlignment.center,
                    crossAxisAlignment: crossAxisAlignmentLabelOnTop ?? CrossAxisAlignment.center,
                    children: [
                      !labelOnTop || label == null
                          ? Container()
                          : Container(
                              alignment: labelAlignOnTop ?? Alignment.center,
                              width: labelWidth,
                              height: labelHeight,
                              color: colorBackGroungTitleContainer != null ? null : colorLabel ?? Colors.transparent,
                              margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
                              decoration: colorBackGroungTitleContainer != null
                                  ? BoxDecoration(
                                      color: colorBackGroungTitleContainer ?? Colors.transparent,
                                      border: Border(
                                        top: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        left: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        right: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        bottom: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                      ))
                                  : null,
                              child: labelWidget ??
                                  Container(
                                    alignment: labelAlignOnTop,
                                    height: labelHeight,
                                    child: Text(
                                      label!,
                                      textAlign: labelTextAlign,
                                      style: labelStyle ?? XStyles.xStyTextForLabel(),
                                    ),
                                  )),
                      Row(children: [
                        labelOnTop || label == null
                            ? Container()
                            : Container(
                                alignment: labelAlignOnLeft ?? Alignment.center,
                                width: labelWidth,
                                height: labelHeight,
                                padding: EdgeInsets.symmetric(vertical: 2),
                                color: colorLabel ?? Colors.transparent,
                                margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
                                child: labelWidget ??
                                    Container(
                                      height: labelHeight,
                                      child: Text(
                                        label!,
                                        textAlign: labelTextAlign,
                                        style: labelStyle ?? XStyles.xStyTextForLabel(),
                                      ),
                                    )),
                        Expanded(
                          // color: Colors.white,
                          child: Row(children: [
                            Expanded(
                              child: Wrap(crossAxisAlignment: WrapCrossAlignment.center, spacing: 5, runSpacing: 5, children: children!),
                            ),
                          ]),
                        ),
                      ]),
                    ],
                  )),
            ),
          ),
        ));
  }
}

==> xwidgetsbase-5.0.5.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItem.dart <==
part of xwidgetbase;

class XItem extends StatelessWidget {
  final bool labelOnTop;
  final String? label;
  final Color? colorLabel;
  final TextStyle? labelStyle;
  final Widget? labelWidget;
  final TextAlign labelTextAlign;
  final double labelContainerWidth;
  final double? labelContainerHeight;
  final AlignmentGeometry? labelAlignOnTop;
  final AlignmentGeometry? labelAlignOnLeft;
  final Color? backGroundColorTitleContainer;
  final double? widthBorderTitleContainer;
  final Color? colorCard;
  final CrossAxisAlignment? crossAxisAlignmentXItem;
  final MainAxisAlignment? mainAxisAlignmentXItem;
  final List<Widget>? children;
  final bool visibleBottomBorderOfCard;
  final CrossAxisAlignment? childrensCrossAxisAlignment;
  final BoxConstraints? constraintsOfXItem;

  final Function()? onTap;
  XItem({
    Key? key,
    this.onTap,
    this.labelAlignOnTop,
    this.mainAxisAlignmentXItem,
    this.labelWidget,
    this.crossAxisAlignmentXItem,
    this.colorCard,
    this.labelStyle,
    this.labelAlignOnLeft,
    this.visibleBottomBorderOfCard = false,
    this.colorLabel,
    this.label = "",
    this.labelContainerWidth = 150,
    this.labelContainerHeight,
    this.children,
    this.childrensCrossAxisAlignment,
    this.labelOnTop = false,
    this.labelTextAlign = TextAlign.center,
    this.backGroundColorTitleContainer,
    this.widthBorderTitleContainer,
    double? width,
    double? height,
    BoxConstraints? constraintsOfXItem,
  })  : constraintsOfXItem = (width != null || height != null) ? constraintsOfXItem?.tighten(width: width, height: height) ?? BoxConstraints.tightFor(width: width, height: height) : constraintsOfXItem,
        super(key: key);
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
        onTap: onTap,
        child: ConstrainedBox(
          constraints: constraintsOfXItem ?? BoxConstraints(),
          child: Container(
            child: Card(
              color: colorCard ?? Colors.transparent,
              child: Container(
                  decoration: visibleBottomBorderOfCard == true ? BoxDecoration(border: Border(bottom: BorderSide(width: 6, color: Colors.blue.withOpacity(0.5)))) : null,
                  child: Column(
                    mainAxisAlignment: mainAxisAlignmentXItem ?? MainAxisAlignment.center,
                    crossAxisAlignment: crossAxisAlignmentXItem ?? CrossAxisAlignment.center,
                    children: [
                      !labelOnTop || label == null
                          ? Container()
                          : Container(
                              alignment: labelAlignOnTop ?? Alignment.center,
                              width: labelContainerWidth,
                              height: labelContainerHeight,
                              color: backGroundColorTitleContainer != null ? null : colorLabel ?? Colors.transparent,
                              margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
                              decoration: backGroundColorTitleContainer != null
                                  ? BoxDecoration(
                                      color: backGroundColorTitleContainer ?? Colors.transparent,
                                      border: Border(
                                        top: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        left: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        right: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                        bottom: BorderSide(color: colorLabel ?? Colors.transparent, width: widthBorderTitleContainer ?? 2),
                                      ))
                                  : null,
                              child: labelWidget ??
                                  Container(
                                    alignment: labelAlignOnTop,
                                    height: labelContainerHeight,
                                    child: Text(label!, textAlign: labelTextAlign, style: labelStyle ?? XStyles.xStyTextForLabel()),
                                  )),
                      Row(children: [
                        labelOnTop || label == null
                            ? Container()
                            : Container(
                                alignment: labelAlignOnLeft ?? Alignment.center,
                                width: labelContainerWidth,
                                height: labelContainerHeight,
                                padding: EdgeInsets.symmetric(vertical: 2),
                                color: colorLabel ?? Colors.transparent,
                                margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
                                child: labelWidget ??
                                    Container(
                                      height: labelContainerHeight,
                                      child: Text(
                                        label!,
                                        textAlign: labelTextAlign,
                                        style: labelStyle ?? XStyles.xStyTextForLabel(),
                                      ),
                                    )),
                        Expanded(
                          // color: Colors.white,
                          child: Row(children: [
                            Expanded(
                              child: Wrap(crossAxisAlignment: WrapCrossAlignment.center, spacing: 5, runSpacing: 5, children: children!),
                            ),
                          ]),
                        ),
                      ]),
                    ],
                  )),
            ),
          ),
        ));
  }
}
